==> flulm_auth-0.1.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/FlulmAuthPlugin.java <==
package com.awesome.flulm_auth;

import com.awesome.flulm_auth.constant.LMPluginMethods;
import com.awesome.flulm_auth.handler.FluLmRequestHandler;
import com.awesome.flulm_auth.handler.FluLmResponseHandler;
import com.awesome.flulm_auth.handler.FlulmAuthHandler;
import com.awesome.flulm_auth.handler.LmAPiHandler;

import io.flutter.Log;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * @author dashu
 * @date 2019-07-30
 * describe:
 */
public class FlulmAuthPlugin implements MethodChannel.MethodCallHandler {

    private FlulmAuthHandler mFlulmAuthHandler;

    public FlulmAuthPlugin(MethodChannel mMethodChannel) {
        mFlulmAuthHandler = new FlulmAuthHandler(mMethodChannel);
    }

    public static void registerWith(PluginRegistry.Registrar registrar) {
        MethodChannel channel = new MethodChannel(registrar.messenger(), "com.awesome/flulm_auth");
        //注册上下文 给api
        LmAPiHandler.INSTANCE.setRegistrar(registrar);
        FluLmRequestHandler.INSTANCE.setRegistrar(registrar);
        FluLmResponseHandler.INSTANCE.setMethodChannel(channel);
        channel.setMethodCallHandler(new FlulmAuthPlugin(channel));
    }

    @Override
    public void onMethodCall(MethodCall call, MethodChannel.Result result) {
        Log.d("azhansy", "onMethodCall=>" + call.method);
        if (call.method.equals(LMPluginMethods.REGISTER_APP)) {
            LmAPiHandler.INSTANCE.registerApp(call, result);
            return;
        }


        if (call.method.equals(LMPluginMethods.UNREGISTER_APP)) {
            return;

        }

        if (call.method.equals(LMPluginMethods.IS_LM_INSTALLED)) {
            LmAPiHandler.INSTANCE.checkInstallation(result);
            return;
        }
        if (call.method.equals(LMPluginMethods.IS_LM_SUPPORT_API)) {
            LmAPiHandler.INSTANCE.getSupportAPI(result);
            return;
        }

        if (call.method.equals(LMPluginMethods.SEND_AUTH)) {
            mFlulmAuthHandler.sendAuth(call, result);
            return;

        }
        result.notImplemented();

    }
}

==> flulm_auth-0.2.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/FlulmAuthPlugin.java <==
package com.awesome.flulm_auth;

import com.awesome.flulm_auth.constant.LMPluginMethods;
import com.awesome.flulm_auth.handler.FluLmRequestHandler;
import com.awesome.flulm_auth.handler.FluLmResponseHandler;
import com.awesome.flulm_auth.handler.FlulmAuthHandler;
import com.awesome.flulm_auth.handler.LmAPiHandler;

import io.flutter.Log;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * @author dashu
 * @date 2019-07-30
 * describe:
 */
public class FlulmAuthPlugin implements MethodChannel.MethodCallHandler {

    private FlulmAuthHandler mFlulmAuthHandler;

    public FlulmAuthPlugin(MethodChannel mMethodChannel) {
        mFlulmAuthHandler = new FlulmAuthHandler(mMethodChannel);
    }

    public static void registerWith(PluginRegistry.Registrar registrar) {
        MethodChannel channel = new MethodChannel(registrar.messenger(), "com.awesome/flulm_auth");
        //注册上下文 给api
        LmAPiHandler.INSTANCE.setRegistrar(registrar);
        FluLmRequestHandler.INSTANCE.setRegistrar(registrar);
        FluLmResponseHandler.INSTANCE.setMethodChannel(channel);
        channel.setMethodCallHandler(new FlulmAuthPlugin(channel));
    }

    @Override
    public void onMethodCall(MethodCall call, MethodChannel.Result result) {
        Log.d("AwesomeAuth", "onMethodCall=>" + call.method);
        if (call.method.equals(LMPluginMethods.REGISTER_APP)) {
            LmAPiHandler.INSTANCE.registerApp(call, result);
            return;
        }


        if (call.method.equals(LMPluginMethods.UNREGISTER_APP)) {
            return;

        }

        if (call.method.equals(LMPluginMethods.IS_LM_INSTALLED)) {
            LmAPiHandler.INSTANCE.checkInstallation(result);
            return;
        }
        if (call.method.equals(LMPluginMethods.IS_LM_SUPPORT_API)) {
            LmAPiHandler.INSTANCE.getSupportAPI(result);
            return;
        }

        if (call.method.equals(LMPluginMethods.SEND_AUTH)) {
            mFlulmAuthHandler.sendAuth(call, result);
            return;

        }
        if (call.method.equals(LMPluginMethods.SEND_PAY)) {
            mFlulmAuthHandler.sendPay(call, result);
            return;

        }
        result.notImplemented();

    }
}
